@@ -3,9 +3,6 @@ import json
 from os import path, makedirs
 from os.path import basename
 from datetime import datetime
-
-from openpyxl import load_workbook
-
 from resources import excel_headers
 from excel2meta_interface.utils import messages, excel
 
@@ -45,21 +42,21 @@ class Excel2Reference:
         overall_result = messages.message["ok"]
         info_datasets = []
         # list of source zones
-        source_zone_column = "zone"
+        source_zone_column = excel_headers.source_zone
         source_zones = self.get_distinct(source_zone_column)
         result = self.out_distinct("REF_-_zones-source" + source_zone_column, source_zones)
         if result["code"] != "OK":
             overall_result = result
 
         # list of target zones
-        target_zone_column = "tgtzone"
+        target_zone_column = excel_headers.target_zone
         target_zones = self.get_distinct(target_zone_column)
         result = self.out_distinct("REF_-_zones-target" + target_zone_column, target_zones)
         if result["code"] != "OK":
             overall_result = result
 
         # source dataset list
-        source_dataset_column = "dataset"
+        source_dataset_column = excel_headers.source_dataset_name
         source_datasets = self.get_distinct(source_dataset_column)
         # get additional info
         info_source_datasets = self.get_dataset_info(source_datasets, "dataset")
@@ -70,7 +67,7 @@ class Excel2Reference:
             overall_result = result
 
         # target dataset list
-        target_dataset_column = "tgtdataset"
+        target_dataset_column = excel_headers.target_dataset_name
         target_datasets = self.get_distinct(target_dataset_column)
         # get additional info
         info_target_datasets = self.get_dataset_info(target_datasets, "tgtdataset")
@@ -86,7 +83,7 @@ class Excel2Reference:
         tgt_zone, row = self.search_value_in_row_index(search_string=target_zone_column, row=1)
         src_tgt_zones = self.get_distinct_combined(src_zone, tgt_zone)
         result = self.out_distinct_combined("MAP_-_zones-source2target"
-                                             + source_zone_column + '_' + target_zone_column, src_tgt_zones)
+                                            + source_zone_column + '_' + target_zone_column, src_tgt_zones)
         if result["code"] != "OK":
             overall_result = result
 
@@ -101,9 +98,9 @@ class Excel2Reference:
                                                             , target_dataset=tgt_dataset
                                                             )
         result = self.out_distinct_combined("MAP_-_data-sources-source2target"
-                                             + source_zone_column + "." + source_dataset_column
-                                             + "_" + target_zone_column + "." + target_dataset_column
-                                             , src_tgt_zones_datasets)
+                                            + source_zone_column + "." + source_dataset_column
+                                            + "_" + target_zone_column + "." + target_dataset_column
+                                            , src_tgt_zones_datasets)
         if result["code"] != "OK":
             overall_result = result
 
@@ -256,17 +253,17 @@ class Excel2Reference:
                 #                , tgt_zone=tgt_zone
                 #                )
                 combined = dict(
-                      source=source_value
+                    source=source_value
                     , source_dataset=source_dataset_value
                     , target=target_value
                     , target_dataset=target_dataset_value
                     , application_id=self.work_sheet.cell(row=i, column=app_column).value
                     , dataset_id=str(self.work_sheet.cell(row=i, column=id_column).value)
-                    , src_layer = src_layer
+                    , src_layer=src_layer
                     , src_zone=src_zone
                     , src_area=src_area
                     , src_system=src_system
-                    , tgt_layer = tgt_layer
+                    , tgt_layer=tgt_layer
                     , tgt_zone=tgt_zone
                     , tgt_area=tgt_area
                     , tgt_system=tgt_system
@@ -328,7 +325,8 @@ class Excel2Reference:
         return values
 
     def search_value_in_row_index(self, search_string, row=1):
-        return self.excel_utils.search_value_in_row_index(work_sheet=self.work_sheet, search_string=search_string, row=row)
+        return self.excel_utils.search_value_in_row_index(work_sheet=self.work_sheet, search_string=search_string,
+                                                          row=row)
 
     def search_value_in_column_index(self, search_string, column, give_column, give_column2=None,
                                      name_column1=None, name_column2=None, give_list=False):
@@ -344,7 +342,9 @@ class Excel2Reference:
                     # print(cell.value)
                     if not give_list:
                         # we found it and we should not provide an entire list, so return to caller
-                        return str(self.work_sheet.cell(row=cell.row, column=give_column).value).replace('"','\"').replace('\\n',' ')
+                        return str(self.work_sheet.cell(row=cell.row, column=give_column).value).replace('"',
+                                                                                                         '\"').replace(
+                            '\\n', ' ')
                     else:
                         if give_column2 is None:
                             value = self.work_sheet.cell(row=cell.row, column=give_column).value
@@ -401,11 +401,15 @@ class Excel2Reference:
         # csv
         file_name = out_file + ".csv"
         try:
-            keys = result_list[0].keys()
-            with open(file_name, "w", encoding="utf8", newline='') as csv_file:
-                dict_writer = csv.DictWriter(csv_file, keys, quotechar='"', quoting=csv.QUOTE_NONNUMERIC)
-                dict_writer.writeheader()
-                dict_writer.writerows(result_list)
+            print(result_list)
+            if len(result_list) > 0:
+                keys = result_list[0].keys()
+                with open(file_name, "w", encoding="utf8", newline='') as csv_file:
+                    dict_writer = csv.DictWriter(csv_file, keys, quotechar='"', quoting=csv.QUOTE_NONNUMERIC)
+                    dict_writer.writeheader()
+                    dict_writer.writerows(result_list)
+            else:
+                print("Empty result list. Output file >%s< not created" % (out_file + ".csv"))
         except IOError:
             result = messages.message["write_error"]
             result["info"] = "Error creating or writing dictionary to csv output file >" + file_name + "<."
