@@ -193,17 +193,19 @@ class JSON2EDCLineageFiles:
         if file is None:
             print("Could not find a dataset REF file for >%s< >%s<" % (src_or_tgt, dataset_name))
             return None
-        # print("Using ref file:", file)
+        print("Using ref file:", file)
         data = None
         with open(file, "r") as the_file:
             data = json.load(the_file)
         if src_or_tgt == "source":
             for source in data:
                 if source["dataset"] == dataset_name:
+                    print("found entry for dataset >%s<" % dataset_name, source)
                     return source
         elif src_or_tgt == "target":
             for entry in data:
                 if entry["dataset"] == dataset_name:
+                    print("found entry for dataset >%s<" % dataset_name, entry)
                     return entry
         else:
             print("Incorrect src_or_tgt:", src_or_tgt)
