@@ -8,9 +8,9 @@ from excel2meta_interface.utils import messages
 
 
 class ProcessOneOnOneLineageEDC:
-    def __init__(self):
+    def __init__(self, configuration_directory="lineage_output/one-on-one/config/"):
         self.result = messages.message["ok"]
-        self.config_directory = "lineage_output/one-on-one/config/"
+        self.config_directory = configuration_directory
 
     def upload_lineage(self):
         overall_result = messages.message["ok"]
